==> am_mod_grp_0_1.zip: am_mod_grp_0_1/components/grp/inc/grp_item_select.function.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// this function is used to return a single row as an item array
// the core uses this to obtain a row and return it in a format it
// can understand

function selItemModule_grp($group_id, $subject_id = null) {
	
	global $db;
	
	$item = array();
	
	if (isset($subject_id)) {
		$query = "
			SELECT subject_id, subject_title 
			FROM " . $db->prefix . "_group_subject 
			WHERE 
			group_id=" . $group_id . " AND 
			subject_id=" . $subject_id
		;
			
		$result = $db->SelectLimit($query, 1);
		
		if (isset($result->fields)) {
			$item['item_title'] = $result->fields['subject_title'];
			$item['item_url'] = "index.php?amn=grp_item&amp;group_id=" . $result->fields['group_id'] . "&amp;subject_id=" . $result->fields['subject_id'];
			
			return $item;
		}
	}
	else {
		$query = "
			SELECT group_id, group_title 
			FROM " . $db->prefix . "_group 
			WHERE 
			group_id=" . $group_id
		;
			
		$result = $db->SelectLimit($query, 1);
		
		if (isset($result->fields)) {
			$item['item_title'] = $result->fields['group_title'];
			$item['item_url'] = "index.php?amn=grp_item&amp;group_id=" . $result->fields['group_id'];
			
			return $item;
		}
	}
}

?>

==> am_mod_grp_0_4.zip: am_mod_grp_0_4/components/grp/inc/grp_item_select.function.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// this function is used to return a single row as an item array
// the core uses this to obtain a row and return it in a format it
// can understand

function selItemModule_grp($group_id, $subject_id = null) {
	
	global $db;
	
	$item = array();
	
	if (isset($subject_id)) {
		$query = "
			SELECT group_id, subject_id, subject_title
			FROM " . $db->prefix . "_group_subject 
			WHERE 
			group_id=" . $group_id . " AND 
			subject_id=" . $subject_id
		;
		
		$result = $db->SelectLimit($query, 1);
		
		if (isset($result->fields)) {
			$item['item_title'] = $result->fields['subject_title'];
			$item['item_url'] = "index.php?amn=grp_item&amp;group_id=" . $result->fields['group_id'] . "&amp;subject_id=" . $result->fields['subject_id'];
			
			return $item;
		}
	}
	else {
		$query = "
			SELECT group_id, group_title 
			FROM " . $db->prefix . "_group 
			WHERE 
			group_id=" . $group_id
		;
			
		$result = $db->SelectLimit($query, 1);
		
		if (isset($result->fields)) {
			$item['item_title'] = $result->fields['group_title'];
			$item['item_url'] = "index.php?amn=grp_item&amp;group_id=" . $result->fields['group_id'];
			
			return $item;
		}
	}
}

?>
